@@ -2,11 +2,13 @@ from os import sep
 import os.path
 import re
 
+import django
 from django.views.generic import View, TemplateView
 from django.conf import settings
 from django.core.urlresolvers import reverse
 from django.template.defaultfilters import timesince
 
+import datatableview
 from datatableview.views import DatatableView, XEditableDatatableView
 from datatableview.utils import get_datatable_structure
 from datatableview import helpers
@@ -40,6 +42,12 @@ class IndexView(TemplateView):
         context['working_directory'] = working_directory
         context['os_sep'] = sep
 
+        # Versions
+        context.update({
+            'datatableview_version': '.'.join(map(str, datatableview.__version_info__)),
+            'django_version': django.get_version(),
+        })
+
         return context
 
 
