@@ -1,5 +1,8 @@
 from collections import namedtuple
-
+try:
+    from functools import reduce
+except ImportError:
+    pass
 try:
     from collections import UserDict
 except ImportError:
@@ -10,6 +13,8 @@ from django.template.loader import render_to_string
 from django.utils.encoding import StrAndUnicode
 from django.forms.util import flatatt
 
+import six
+
 # Sane boundary constants
 MINIMUM_PAGE_LENGTH = 5
 
@@ -154,8 +159,8 @@ class DatatableStructure(StrAndUnicode):
         self.model = model
 
         self.ordering = {}
-        if options.ordering:
-            for i, name in enumerate(options.ordering):
+        if options['ordering']:
+            for i, name in enumerate(options['ordering']):
                 plain_name = name.lstrip('-+')
                 index = options.get_column_index(plain_name)
                 if index == -1:
@@ -164,7 +169,7 @@ class DatatableStructure(StrAndUnicode):
                 self.ordering[plain_name] = ColumnOrderingTuple(i, index, sort_direction)
 
     def __unicode__(self):
-        return render_to_string(self.options.structure_template, {
+        return render_to_string(self.options['structure_template'], {
             'url': self.url,
             'result_counter_id': self.options['result_counter_id'],
             'column_info': self.get_column_info(),
@@ -195,7 +200,7 @@ class DatatableStructure(StrAndUnicode):
         else:
             model_fields = []
 
-        for column in self.options.columns:
+        for column in self.options['columns']:
             column = get_field_definition(column)
             pretty_name = column.pretty_name
             column_name = column.pretty_name
@@ -215,12 +220,12 @@ class DatatableStructure(StrAndUnicode):
 
     def get_column_attributes(self, name):
         attributes = {
-            'data-sortable': _javascript_boolean[name not in self.options.unsortable_columns],
-            'data-visible': _javascript_boolean[name not in self.options.hidden_columns],
+            'data-sortable': _javascript_boolean[name not in self.options['unsortable_columns']],
+            'data-visible': _javascript_boolean[name not in self.options['hidden_columns']],
         }
 
         if name in self.ordering:
-            attributes['data-sorting'] = ','.join(map(unicode, self.ordering[name]))
+            attributes['data-sorting'] = ','.join(map(six.text_type, self.ordering[name]))
 
         return attributes
 
@@ -234,7 +239,7 @@ class DatatableOptions(UserDict):
         # Core options, not modifiable by client updates
         if 'columns' not in kwargs:
             model_fields = model._meta.local_fields
-            kwargs['columns'] = map(lambda f: (f.verbose_name, f.name), model_fields)
+            kwargs['columns'] = list(map(lambda f: (f.verbose_name, f.name), model_fields))
 
         if 'hidden_columns' not in kwargs or kwargs['hidden_columns'] is None:
             kwargs['hidden_columns'] = []
@@ -251,19 +256,13 @@ class DatatableOptions(UserDict):
         UserDict.__init__(self, DEFAULT_OPTIONS, *args, **kwargs)
 
         self._flat_column_names = []
-        for column in self.columns:
+        for column in self['columns']:
             column = get_field_definition(column)
             flat_name = column.pretty_name
             if column.fields:
                 flat_name = column.fields[0]
             self._flat_column_names.append(flat_name)
 
-    def __getattr__(self, k):
-        try:
-            return self.data[k]
-        except KeyError:
-            raise AttributeError("%s doesn't support option %r" % (self.__class__.__name__, k))
-
     def _normalize_options(self, query, options):
         """ Validates incoming options in the request query parameters. """
 
@@ -418,7 +417,7 @@ def filter_real_fields(model, fields, key=None):
 
     """
 
-    field_hints = zip(map(key, fields), fields)
+    field_hints = tuple(zip(map(key, fields), fields))
     field_map = dict(field_hints)
     field_list = set(field_map.keys())
     concrete_names = set(model._meta.get_all_field_names())
